import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * AWS SageMaker.
 *
 * @stability stable
 */
export interface SagemakerProjectConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#project_description SagemakerProject#project_description}.
     *
     * @stability stable
     */
    readonly projectDescription?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#project_name SagemakerProject#project_name}.
     *
     * @stability stable
     */
    readonly projectName: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#tags SagemakerProject#tags}.
     *
     * @stability stable
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#tags_all SagemakerProject#tags_all}.
     *
     * @stability stable
     */
    readonly tagsAll?: {
        [key: string]: string;
    };
    /**
     * service_catalog_provisioning_details block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#service_catalog_provisioning_details SagemakerProject#service_catalog_provisioning_details}
     *
     * @stability stable
     */
    readonly serviceCatalogProvisioningDetails: SagemakerProjectServiceCatalogProvisioningDetails;
}
/**
 * @stability stable
 */
export interface SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#key SagemakerProject#key}.
     *
     * @stability stable
     */
    readonly key: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#value SagemakerProject#value}.
     *
     * @stability stable
     */
    readonly value?: string;
}
export declare function sagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameterToTerraform(struct?: SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter | cdktf.IResolvable): any;
/**
 * @stability stable
 */
export interface SagemakerProjectServiceCatalogProvisioningDetails {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#path_id SagemakerProject#path_id}.
     *
     * @stability stable
     */
    readonly pathId?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#product_id SagemakerProject#product_id}.
     *
     * @stability stable
     */
    readonly productId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#provisioning_artifact_id SagemakerProject#provisioning_artifact_id}.
     *
     * @stability stable
     */
    readonly provisioningArtifactId?: string;
    /**
     * provisioning_parameter block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project#provisioning_parameter SagemakerProject#provisioning_parameter}
     *
     * @stability stable
     */
    readonly provisioningParameter?: SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter[] | cdktf.IResolvable;
}
export declare function sagemakerProjectServiceCatalogProvisioningDetailsToTerraform(struct?: SagemakerProjectServiceCatalogProvisioningDetailsOutputReference | SagemakerProjectServiceCatalogProvisioningDetails): any;
/**
 * @stability stable
 */
export declare class SagemakerProjectServiceCatalogProvisioningDetailsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): SagemakerProjectServiceCatalogProvisioningDetails | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: SagemakerProjectServiceCatalogProvisioningDetails | undefined);
    private _pathId?;
    /**
     * @stability stable
     */
    get pathId(): string;
    /**
     * @stability stable
     */
    set pathId(value: string);
    /**
     * @stability stable
     */
    resetPathId(): void;
    /**
     * @stability stable
     */
    get pathIdInput(): string | undefined;
    private _productId?;
    /**
     * @stability stable
     */
    get productId(): string;
    /**
     * @stability stable
     */
    set productId(value: string);
    /**
     * @stability stable
     */
    get productIdInput(): string | undefined;
    private _provisioningArtifactId?;
    /**
     * @stability stable
     */
    get provisioningArtifactId(): string;
    /**
     * @stability stable
     */
    set provisioningArtifactId(value: string);
    /**
     * @stability stable
     */
    resetProvisioningArtifactId(): void;
    /**
     * @stability stable
     */
    get provisioningArtifactIdInput(): string | undefined;
    private _provisioningParameter?;
    /**
     * @stability stable
     */
    get provisioningParameter(): SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter[] | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set provisioningParameter(value: SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter[] | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetProvisioningParameter(): void;
    /**
     * @stability stable
     */
    get provisioningParameterInput(): cdktf.IResolvable | SagemakerProjectServiceCatalogProvisioningDetailsProvisioningParameter[] | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project aws_sagemaker_project}.
 *
 * @stability stable
 */
export declare class SagemakerProject extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_project aws_sagemaker_project} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: SagemakerProjectConfig);
    /**
     * @stability stable
     */
    get arn(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _projectDescription?;
    /**
     * @stability stable
     */
    get projectDescription(): string;
    /**
     * @stability stable
     */
    set projectDescription(value: string);
    /**
     * @stability stable
     */
    resetProjectDescription(): void;
    /**
     * @stability stable
     */
    get projectDescriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get projectId(): string;
    private _projectName?;
    /**
     * @stability stable
     */
    get projectName(): string;
    /**
     * @stability stable
     */
    set projectName(value: string);
    /**
     * @stability stable
     */
    get projectNameInput(): string | undefined;
    private _tags?;
    /**
     * @stability stable
     */
    get tags(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tags(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTags(): void;
    /**
     * @stability stable
     */
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _tagsAll?;
    /**
     * @stability stable
     */
    get tagsAll(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set tagsAll(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetTagsAll(): void;
    /**
     * @stability stable
     */
    get tagsAllInput(): {
        [key: string]: string;
    } | undefined;
    private _serviceCatalogProvisioningDetails;
    /**
     * @stability stable
     */
    get serviceCatalogProvisioningDetails(): SagemakerProjectServiceCatalogProvisioningDetailsOutputReference;
    /**
     * @stability stable
     */
    putServiceCatalogProvisioningDetails(value: SagemakerProjectServiceCatalogProvisioningDetails): void;
    /**
     * @stability stable
     */
    get serviceCatalogProvisioningDetailsInput(): SagemakerProjectServiceCatalogProvisioningDetails | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
